@@ -88,6 +88,8 @@ struct App {
     auth_token: Option<String>,
     joined_rooms: Vec<RoomId>,
     room_to_direct_name: BTreeMap<RoomId, String>,
+    room_to_aliases: BTreeMap<RoomId, Vec<RoomAliasId>>,
+    alias_to_room: BTreeMap<RoomAliasId, RoomId>,
     room_list_top: usize,
     room_list_height: usize,
     room_list_top_backup: usize,
@@ -131,6 +133,8 @@ impl App {
             current_room: None,
             rooms: BTreeMap::new(),
             room_id_to_canonical_alias: BTreeMap::new(),
+            alias_to_room: BTreeMap::new(),
+            room_to_aliases: BTreeMap::new(),
             joined_rooms: Vec::new(),
             auth_token: auth_token,
             room: room,
@@ -229,6 +233,8 @@ enum SyncMessage {
         BTreeMap<RoomId, Box<RoomName>>,
         BTreeMap<RoomId, RoomAliasId>,
         BTreeMap<RoomId, String>,
+        BTreeMap<RoomId, Vec<RoomAliasId>>,
+        BTreeMap<RoomAliasId, RoomId>,
     ),
     LeaveRoom(RoomId),
     JoinRoom(String),
@@ -290,6 +296,8 @@ async fn run_app<B: Backend>(terminal: &mut Terminal<B>, mut app: App) -> io::Re
                     client.data.room_to_name.clone(),
                     client.data.room_id_to_cananoical_alias.clone(),
                     client.data.room_to_direct_name.clone(),
+                    client.data.room_to_aliases.clone(),
+                    client.data.alias_to_room.clone(),
                 ))
                 .unwrap();
             }
@@ -518,6 +526,8 @@ async fn run_app<B: Backend>(terminal: &mut Terminal<B>, mut app: App) -> io::Re
                     room_to_name,
                     room_id_to_canonical_alias,
                     room_to_direct_name,
+                    room_to_aliases,
+                    alias_to_room,
                 ) = msg
                 {
                     //app.rooms = room_id_list;
@@ -525,6 +535,8 @@ async fn run_app<B: Backend>(terminal: &mut Terminal<B>, mut app: App) -> io::Re
                     app.rooms = room_to_name;
                     app.room_id_to_canonical_alias = room_id_to_canonical_alias;
                     app.room_to_direct_name = room_to_direct_name;
+                    app.room_to_aliases = room_to_aliases;
+                    app.alias_to_room = alias_to_room;
                     for room_id in room_id_list {
                         if !app.messages.contains_key(&room_id) {
                             app.messages.insert(room_id.clone(), Vec::new());
@@ -721,11 +733,18 @@ fn ui<B: Backend>(f: &mut Frame<B>, app: &mut App) {
                     "{}",
                     app.room_id_to_canonical_alias[room_id]
                 )))];
-            } else {
+            } else if app.room_to_aliases.contains_key(&room_id) {
+                content = vec![Spans::from(Span::raw(format!(
+                    "{}",
+                    app.room_to_aliases[room_id][0]
+                )))];
+            } else if app.room_to_direct_name.contains_key(&room_id) {
                 content = vec![Spans::from(Span::raw(format!(
                     "{}",
                     app.room_to_direct_name[room_id]
                 )))];
+            } else {
+                content = vec![Spans::from(Span::raw(format!("{}", room_id)))];
             }
             //let content: Vec<Span>;
             if app.current_room.is_none() {
